==> qtjambi-scxml-6.5.3-sources.jar: io/qt/scxml/QScxmlStaticScxmlServiceFactory.java <==
package io.qt.scxml;

import io.qt.*;


/**
 * <p>Creates SCXML service instances from precompiled documents</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qscxmlstaticscxmlservicefactory.html">QScxmlStaticScxmlServiceFactory</a></code></p>
 */
public class QScxmlStaticScxmlServiceFactory extends io.qt.scxml.QScxmlInvokableServiceFactory
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlStaticScxmlServiceFactory.class);
    
    
    /**
     * <p>See <code>QScxmlStaticScxmlServiceFactory::<wbr>QScxmlStaticScxmlServiceFactory(const QMetaObject*,<wbr>QScxmlExecutableContent::InvokeInfo,<wbr>QList&lt;QScxmlExecutableContent::StringId&gt;,<wbr>QList&lt;QScxmlExecutableContent::ParameterInfo&gt;,<wbr>QObject*)</code></p>
     */
    public QScxmlStaticScxmlServiceFactory(io.qt.core.@Nullable QMetaObject metaObject, io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo, java.util.@NonNull Collection<java.lang.@QtPrimitiveType@NonNull Integer> nameList, java.util.@NonNull Collection<? extends io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters, io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, metaObject, invokeInfo, nameList, parameters, parent);
    }
    
    private native static void initialize_native(QScxmlStaticScxmlServiceFactory instance, io.qt.core.QMetaObject metaObject, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.@QtPrimitiveType Integer> nameList, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invoke">QScxmlInvokableServiceFactory::<wbr>invoke(QScxmlStateMachine*)</a></code></p>
     */
    @QtUninvokable
    @Override
    public io.qt.scxml.@Nullable QScxmlInvokableService invoke(io.qt.scxml.@Nullable QScxmlStateMachine parentStateMachine){
        return invoke_native_QScxmlStateMachine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parentStateMachine));
    }
    
    @QtUninvokable
    private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QScxmlStaticScxmlServiceFactory(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded constructor for {@link #QScxmlStaticScxmlServiceFactory(io.qt.core.QMetaObject, io.qt.scxml.QScxmlExecutableContent.InvokeInfo, java.util.Collection, java.util.Collection, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScxmlStaticScxmlServiceFactory(io.qt.core.@Nullable QMetaObject metaObject, io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo, java.util.@NonNull Collection<java.lang.@QtPrimitiveType@NonNull Integer> nameList, java.util.@NonNull Collection<? extends io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters) {
        this(metaObject, invokeInfo, nameList, parameters, (io.qt.core.QObject)null);
    }
}

==> qtjambi-scxml-6.7.0-sources.jar: io/qt/scxml/QScxmlStaticScxmlServiceFactory.java <==
package io.qt.scxml;

import io.qt.*;


/**
 * <p>Creates SCXML service instances from precompiled documents</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qscxmlstaticscxmlservicefactory.html">QScxmlStaticScxmlServiceFactory</a></code></p>
 */
public class QScxmlStaticScxmlServiceFactory extends io.qt.scxml.QScxmlInvokableServiceFactory
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlStaticScxmlServiceFactory.class);
    
    
    /**
     * <p>See <code>QScxmlStaticScxmlServiceFactory::<wbr/>QScxmlStaticScxmlServiceFactory(const QMetaObject*,<wbr/>QScxmlExecutableContent::InvokeInfo,<wbr/>QList&lt;QScxmlExecutableContent::StringId&gt;,<wbr/>QList&lt;QScxmlExecutableContent::ParameterInfo&gt;,<wbr/>QObject*)</code></p>
     */
    public QScxmlStaticScxmlServiceFactory(io.qt.core.@Nullable QMetaObject metaObject, io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo, java.util.@NonNull Collection<java.lang.@QtPrimitiveType@NonNull Integer> nameList, java.util.@NonNull Collection<? extends io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters, io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, metaObject, invokeInfo, nameList, parameters, parent);
    }
    
    private native static void initialize_native(QScxmlStaticScxmlServiceFactory instance, io.qt.core.QMetaObject metaObject, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.@QtPrimitiveType Integer> nameList, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invoke">QScxmlInvokableServiceFactory::<wbr/>invoke(QScxmlStateMachine*)</a></code></p>
     */
    @QtUninvokable
    @Override
    public io.qt.scxml.@Nullable QScxmlInvokableService invoke(io.qt.scxml.@Nullable QScxmlStateMachine parentStateMachine){
        return invoke_native_QScxmlStateMachine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parentStateMachine));
    }
    
    @QtUninvokable
    private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QScxmlStaticScxmlServiceFactory(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded constructor for {@link #QScxmlStaticScxmlServiceFactory(io.qt.core.QMetaObject, io.qt.scxml.QScxmlExecutableContent.InvokeInfo, java.util.Collection, java.util.Collection, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScxmlStaticScxmlServiceFactory(io.qt.core.@Nullable QMetaObject metaObject, io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo, java.util.@NonNull Collection<java.lang.@QtPrimitiveType@NonNull Integer> nameList, java.util.@NonNull Collection<? extends io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters) {
        this(metaObject, invokeInfo, nameList, parameters, (io.qt.core.QObject)null);
    }
}
